@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -163,7 +163,7 @@ impl Kubectl {
         }
     }
 
-    async fn get_client(&self) -> anyhow::Result<Client> {
+    async fn get_config(&self) -> anyhow::Result<Config> {
         let context = Some(self.context.clone());
         let options = KubeConfigOptions {
             context,
@@ -172,7 +172,12 @@ impl Kubectl {
         let kubeconfig = self.kubeconfig.clone();
         Config::from_custom_kubeconfig(kubeconfig, &options)
             .await
-            .context("Loading context from kubeconfig")?
+            .context("Loading context from kubeconfig")
+    }
+
+    async fn get_client(&self) -> anyhow::Result<Client> {
+        self.get_config()
+            .await?
             .try_into()
             .context("Connecting to Kubernetes cluster")
     }
@@ -370,8 +375,8 @@ impl Kubectl {
         let cluster = self.create_statehub_cluster(namespace).await?;
         log::debug!("Created StatehubCluster: {:#?}", cluster);
 
-        let client = self.get_client().await?;
-        let statehub_kubectl = statehub_cluster_operator::cluster::Kubectl::new(client);
+        let config = self.get_config().await?;
+        let statehub_kubectl = statehub_cluster_operator::cluster::Operator::with_config(config)?;
         let namespace = statehub_kubectl.ensure_namespace_exists(&cluster).await?;
         log::debug!("Created namespace: {:#?}", namespace);
         Ok(())
