@@ -22,10 +22,10 @@ impl Kubectl {
                 "kind": "Secret",
                 "metadata": {
                     "name": name,
-                    "resource_version": secret.resource_version(),
+                    "resourceVersion": secret.resource_version(),
                 },
                 "type": r#type,
-                "string_data": string_data,
+                "stringData": string_data,
             }))?;
 
             (secret, true)
@@ -37,7 +37,7 @@ impl Kubectl {
                     "name": name,
                 },
                 "type": r#type,
-                "string_data": string_data
+                "stringData": string_data,
             }))?;
 
             (secret, false)
