@@ -19,7 +19,8 @@
 #![deny(warnings)]
 #![cfg_attr(result_option_inspect, feature(result_option_inspect))]
 
-use statehub_api::{location, v0};
+use statehub_api::v0;
+use statehub_location as location;
 
 use output::Output;
 use statehub::Cli;
