@@ -40,7 +40,7 @@ mod print;
 const ABOUT: &str = "statehub CLI tool";
 
 #[derive(Debug, clap::Parser)]
-#[clap(about = ABOUT)]
+#[clap(about = ABOUT, version)]
 pub(crate) struct Cli {
     #[clap(
         help = "Management server URL or address",
