@@ -3,22 +3,22 @@
 // Use is subject to license terms.
 //
 
+use clap::Parser;
 use serde::{Deserialize, Serialize};
 use serde_with::skip_serializing_none;
-use structopt::StructOpt;
 
 #[skip_serializing_none]
-#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, StructOpt)]
+#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, Parser)]
 #[serde(rename_all = "UPPERCASE")]
 pub(crate) struct AzureCredentials {
-    // #[structopt(help = "Azure Tenant ID", long, requires_all = &["azure_client_id", "azure_client_secret"])]
-    #[structopt(help = "Azure Tenant ID", long)]
+    // #[clap(help = "Azure Tenant ID", long, requires_all = &["azure_client_id", "azure_client_secret"])]
+    #[clap(help = "Azure Tenant ID", long)]
     azure_tenant_id: Option<String>,
-    // #[structopt(help = "Azure Client ID", long, requires_all = &["azure_tenant_id", "azure_client_secret"])]
-    #[structopt(help = "Azure Client ID", long)]
+    // #[clap(help = "Azure Client ID", long, requires_all = &["azure_tenant_id", "azure_client_secret"])]
+    #[clap(help = "Azure Client ID", long)]
     azure_client_id: Option<String>,
-    // #[structopt(help = "Azure Client Secret", long, requires_all = &["azure_tenant_id", "azure_client_id"])]
-    #[structopt(help = "Azure Client Secret", long)]
+    // #[clap(help = "Azure Client Secret", long, requires_all = &["azure_tenant_id", "azure_client_id"])]
+    #[clap(help = "Azure Client Secret", long)]
     azure_client_secret: Option<String>,
 }
 
